@@ -23,7 +23,7 @@ from SeisMonitor.core import utils as scut
 from obspy.core.event.base import CreationInfo
 import concurrent.futures as cf
 from obspy import UTCDateTime
-import mtspec
+# import mtspec
 import numpy as np
 import scipy
 import os
