@@ -43,8 +43,34 @@ from obspy.core.event.base import (QuantityError,
                                 WaveformStreamID,
                                 CreationInfo,
                                 Comment)
+from git import Repo
 from obspy.core.event import ResourceIdentifier
 
+
+def git_clone_aipicker(name,repo_dir):
+    """
+    Params:
+    -------
+    name: str
+        EQTransformer or PhaseNet
+    repo_dir: str
+        Directory path to place the repository
+    """
+    if name == "PhaseNet":
+        git_url = "https://github.com/ecastillot/PhaseNet.git"
+    elif name == "EQTransformer":
+        git_url = "https://github.com/ecastillot/EQTransformer.git"
+    else:
+        return False
+
+    repo_dir = os.path.join(repo_dir,name)
+    if os.path.isdir(repo_dir):
+        print("There is alaready")
+        return True
+    else:
+        Repo.clone_from(git_url, repo_dir)
+        return True
+
 ## EQTransformer functions
 def eqt_picks_2_seismonitor_fmt(eqt_folder,mseed_folder,out_path):
     #eqt
@@ -178,6 +204,8 @@ def get_filenames(mseed, filter_net=[],
     return filenames
 
 def mv_mseed2onefolder(mseed_folder,one_folder):
+    print("aca",mseed_folder)
+    print("aca",one_folder)
     for dp, dn, filenames in os.walk(mseed_folder):
         for f in filenames:
             if f.endswith(".mseed") :
